<?php $TRANSLATIONS = array(
"Pictures" => "Bilder",
"Shared by" => "Geteilt von ",
"Share" => "Teilen",
"The \"Image Viewer\" application also need to be enabled to use this application." => "Die Anwendung \"Image Viewer\" muss aktiviert sein, damit Du diese Anwendung benutzen kannst."
);
